@@ -480,7 +480,8 @@ LstepCE1<-function(x,DLM_data,reps=100,yrsmth=5,xx=0,stepsz=0.05,llim=c(0.96,0.9
   }
  
   Allocate <- 1
-  Effort <- max(0.01,Effort) # for simulations in case Effort goes negative
+  Effort[Effort < 0.01] <- 0.01 # for simulations in case Effort goes negative
+  Effort <- mean(Effort)
   Spatial <- c(1,1)
   Vuln<-rep(NA,3)
   out <- c(Allocate, Effort, Spatial, Vuln)
@@ -508,7 +509,8 @@ LstepCE2<-function(x,DLM_data,reps=100,yrsmth=5,xx=0,stepsz=0.1,llim=c(0.96,0.98
   }else{
     Effort <- DLM_data@MPeff[x]
   }
-  Effort <- max(0.01,Effort) # for simulations in case Effort goes negative
+  Effort[Effort < 0.01] <- 0.01 # for simulations in case Effort goes negative
+  Effort <- mean(Effort)
   Allocate <- 1
   Spatial <- c(1,1)
   Vuln<-rep(NA,3)
@@ -539,7 +541,8 @@ LtargetE1<-function(x,DLM_data,reps=100,yrsmth=5,xx=0,xL=1.05){
 
   Allocate <- 1
   Effort <- Step * DLM_data@MPeff[x]
-  Effort <- max(0.01,Effort) # for simulations in case Effort goes negative
+  Effort[Effort < 0.01] <- 0.01 # for simulations in case Effort goes negative
+  Effort <- mean(Effort)
   Spatial <- c(1,1)
   Vuln<-rep(NA,3)
   out <- c(Allocate, Effort, Spatial, Vuln)
@@ -569,7 +572,8 @@ LtargetE4 <-function(x,DLM_data,reps=100,yrsmth=5,xx=0,xL=1.15){
   Step[Step>1.2] <- 1.2
   Allocate <- 1
   Effort <- Step * DLM_data@MPeff[x]
-  Effort <- max(0.01,Effort) # for simulations in case Effort goes negative
+  Effort[Effort < 0.01] <- 0.01 # for simulations in case Effort goes negative
+  Effort <- mean(Effort)
   Spatial <- c(1,1)
   Vuln<-rep(NA,3)
   out <- c(Allocate, Effort, Spatial, Vuln)
@@ -599,7 +603,8 @@ ItargetE1<-function(x,DLM_data,reps=100,yrsmth=5,xx=0,Imulti=1.5){
   Step[Step>1.15] <- 1.15
   Allocate <- 1
   Effort <- Step * DLM_data@MPeff[x]
-  Effort <- max(0.01,Effort) # for simulations in case Effort goes negative
+  Effort[Effort < 0.01] <- 0.01 # for simulations in case Effort goes negative
+  Effort <- mean(Effort)
   Spatial <- c(1,1)
   Vuln<-rep(NA,3)
   out <- c(Allocate, Effort, Spatial, Vuln) 
@@ -629,7 +634,8 @@ ItargetE4 <-function(x,DLM_data,reps=100,yrsmth=5,xx=0,Imulti=2.5){
 
   Allocate <- 1
   Effort <- Step * DLM_data@MPeff[x]
-  Effort <- max(0.01,Effort) # for simulations in case Effort goes negative
+  Effort[Effort < 0.01] <- 0.01 # for simulations in case Effort goes negative
+  Effort <- mean(Effort)
   Spatial <- c(1,1)
   Vuln<-rep(NA,3)
   out <- c(Allocate, Effort, Spatial, Vuln) 
@@ -647,8 +653,10 @@ ITe10<-function(x,DLM_data,reps=100,yrsmth=5,mc=0.1){
   if(deltaI>(1+mc))deltaI<-1+mc
   
   Effort<-DLM_data@MPeff[x]*deltaI*trlnorm(reps,1,DLM_data@CV_Ind[x])
+  if (reps == 1) Effort<-DLM_data@MPeff[x]*deltaI 
   Allocate <- 1
-  Effort <- max(0.01,Effort) # for simulations in case Effort goes negative
+  Effort[Effort < 0.01] <- 0.01 # for simulations in case Effort goes negative
+  Effort <- mean(Effort)
   Spatial <- c(1,1)
   Vuln<-rep(NA,3)
   out<-c(Allocate, Effort, Spatial, Vuln)
@@ -665,8 +673,10 @@ ITe5<-function(x,DLM_data,reps=100,yrsmth=5,mc=0.05){
   if(deltaI>(1+mc))deltaI<-1+mc
   
   Effort<-DLM_data@MPeff[x]*deltaI*trlnorm(reps,1,DLM_data@CV_Ind[x])
+  if (reps == 1) Effort<-DLM_data@MPeff[x]*deltaI
+  Effort[Effort < 0.01] <- 0.01 # for simulations in case Effort goes negative
+  Effort <- mean(Effort)
   Allocate <- 1  
-  Effort <- max(0.01,Effort) # for simulations in case Effort goes negative
   Spatial <- c(1,1)
   Vuln<-rep(NA,3)
   out<-c(Allocate, Effort, Spatial, Vuln)
@@ -675,3 +685,52 @@ ITe5<-function(x,DLM_data,reps=100,yrsmth=5,mc=0.05){
 class(ITe5)<-"DLM_input"
 
 
+minlenLopt1<-function(x,DLM_data,reps=100,buffer=0.1){
+
+  # Minimum length MPs: Fix length-at-full-selectivity to 0.8*Lopt and set length-at-first-capture 10% below LFs 
+
+  dependencies="DLM_data@MPeff, DLM_data@vbLinf, DLM_data@wlb, DLM_data@Mort, DLM_data@vbK"
+  
+  Lopt<-DLM_data@vbLinf[x]*DLM_data@wlb[x]/((DLM_data@Mort[x]/DLM_data@vbK[x])+DLM_data@wlb[x]) 
+  
+  Allocate<-1
+  Spatial<-c(1,1)
+  newLFS <- Lopt*(0.7+buffer) # Lopt too precautionary, so set it to % below
+  newLFC<-newLFS*0.9
+  Vuln <-c(newLFC, newLFS)
+  Effort<-1
+  
+  out <- c(Allocate, Effort, Spatial, Vuln)
+  out
+  
+}  
+class(minlenLopt1)<-"DLM_input"
+
+
+EtargetLopt<-function(x,DLM_data,reps=100,yrsmth=3, buffer=0.1){
+  
+  # Effort MP: adjust effort up/down if mean length above/below Ltarget 
+  
+  dependencies="DLM_data@Year, DLM_data@ML, DLM_data@L50, DLM_data@MPeff, DLM_data@vbLinf, DLM_data@wlb, DLM_data@Mort, DLM_data@vbK"
+  
+  ind<-(length(DLM_data@Year)-(yrsmth-1)):length(DLM_data@Year) # recent 3 years
+  Lrecent<-mean(DLM_data@ML[ind])
+  Lopt<-DLM_data@vbLinf[x]*DLM_data@wlb[x]/((DLM_data@Mort[x]/DLM_data@vbK[x])+DLM_data@wlb[x]) 
+  ratio<-Lrecent/Lopt
+  
+  Allocate<-1
+  Spatial<-c(1,1)
+  Vuln<-c(NA,2) 
+  w<-0.5
+  Effort<-(1-buffer)*(w+(1-w)*ratio)
+  
+  out <- c(Allocate, Effort, Spatial, Vuln)
+  out
+  
+}  
+class(EtargetLopt)<-"DLM_input"
+
+
+
+
+
